@@ -241,7 +241,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     
     sum_pi_f <- colSums(pi_all[8:16,]) 
     Pi.Vectors <- 
-      data.frame(t(rbind(pi_all, sum_pi_f))) 
+      data.frame(t(rbind(pi_all, sum_pi_f)), stringsAsFactors = TRUE) 
     colnames(Pi.Vectors) <- c("Pi_0000", "Pi_0100", "Pi_0010", "Pi_0001", "Pi_0101", "Pi_1000", "Pi_1010", 
                               "Pi_1001", "Pi_1110", "Pi_1101", "Pi_1011", "Pi_1111", "Pi_0110", "Pi_0011", "Pi_0111", "Pi_1100", "Sum.Pi.f") 
 
@@ -401,7 +401,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     
     sum_pi_f <- colSums(pi_all[8:12,]) 
     Pi.Vectors <- 
-      data.frame(t(rbind(pi_all, sum_pi_f))) 
+      data.frame(t(rbind(pi_all, sum_pi_f)), stringsAsFactors = TRUE) 
     colnames(Pi.Vectors) <- c("Pi_0000", "Pi_0100", "Pi_0010", "Pi_0001", "Pi_0101", 
                               "Pi_1110", "Pi_1101", "Pi_1111", "Pi_0110", "Pi_0011", "Pi_0111", "Pi_1100", "Sum.Pi.f")  
     
@@ -558,7 +558,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     sum_pi_f <- colSums(pi_all[8:12,]) 
     
     Pi.Vectors <- 
-      data.frame(t(rbind(pi_all, sum_pi_f))) 
+      data.frame(t(rbind(pi_all, sum_pi_f)), stringsAsFactors = TRUE) 
     colnames(Pi.Vectors) <- c("Pi_0000", "Pi_0100", "Pi_0001", "Pi_0101", "Pi_1000",  
                               "Pi_1011", "Pi_0011", "Pi_1001", "Pi_1101", "Pi_1111", "Pi_0111", "Pi_1100", "Sum.Pi.f")   
     
@@ -702,7 +702,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
         
     sum_pi_f <- colSums(pi_all[8:9,]) 
     Pi.Vectors <- 
-      data.frame(t(rbind(pi_all, sum_pi_f))) 
+      data.frame(t(rbind(pi_all, sum_pi_f)), stringsAsFactors = TRUE) 
     colnames(Pi.Vectors) <- c("Pi_0000", "Pi_0100", "Pi_0001", "Pi_0101",  
                               "Pi_1101", "Pi_1111", "Pi_0011", "Pi_0111", "Pi_1100", "Sum.Pi.f") 
         
