@@ -5,16 +5,15 @@ test_that("sensitivity_analysis_BinCont_copula() works in a simplified setting",
             n_sim = 2
             set.seed(1)
             sens_results = sensitivity_analysis_BinCont_copula(
-              fitted_model,
-              n_sim,
-              cond_ind = TRUE,
+              fitted_model = fitted_model,
+              n_sim = n_sim,
               lower = c(-1,-1,-1,-1),
               upper = c(1, 1, 1, 1),
               n_prec = 1e3
             )
             expect_equal(
               sens_results[,1],
-              c(0.43244243, 0.30876395),
+              c(0.407801974151, 0.311636096417),
               tolerance = 1e-3
             )
           })
@@ -29,14 +28,13 @@ test_that("sensitivity_analysis_BinCont_copula() works in a simplified setting w
             sens_results = sensitivity_analysis_BinCont_copula(
               fitted_model,
               n_sim,
-              cond_ind = TRUE,
               lower = c(0, 0, 0, 0),
               upper = c(0.95, 0.95, 0.95, 0.95),
               n_prec = 1e3
             )
             expect_equal(
               sens_results[,1],
-              c(0.41079208, 0.3107483),
+              c(0.381826406323, 0.301121119697),
               tolerance = 1e-3
             )
           })
